Package 'rk.svyplot'

Title: An RKWard plugin for creating plots from complex survey data using the 'survey' package.
Description: An RKWard plugin for creating plots from complex survey data using the 'survey' package.
Authors: Alfonso Cano Robles
Maintainer: Alfonso Cano Robles <[email protected]>
License: GPL (>= 3)
Version: 0.0.2
Built: 2026-06-04 09:57:19 UTC
Source: https://github.com/AlfCano/rk.svyplot

Help Index